@@ -18,7 +18,7 @@ sub init
 	my $self = shift;
 	$self->SUPER::init;
 
-	$self->{canonicalize_body_buf} = "";
+	$self->{canonicalize_body_empty_lines} = 0;
 }
 
 sub canonicalize_header
@@ -39,7 +39,7 @@ sub canonicalize_header
 sub canonicalize_body
 {
 	my $self = shift;
-	my ($line) = @_;
+	my ($multiline) = @_;
 
 	#
 	# draft-allman-dkim-base-01.txt, section 3.4.3:
@@ -51,19 +51,31 @@ sub canonicalize_body
 	# (i.e. do not emit empty lines until a following nonempty line
 	# is found)
 	#
-	if ($line eq "\015\012")
-	{
-		$self->{canonicalize_body_buf} .= $line;
-		$line = "";
-	}
-	else
-	{
-		$line = $self->{canonicalize_body_buf} . $line;
-		$self->{canonicalize_body_buf} = "";
-		$self->{canonicalize_body_started} = 1;
+	my $empty_lines = $self->{canonicalize_body_empty_lines};
+
+	if ( $multiline =~ s/^((?:\015\012)+)// )
+	{	# count & strip leading empty lines
+		$empty_lines += length($1)/2;
 	}
 
-	return $line;
+	if (length($multiline) > 0)
+	{
+		$self->{canonicalize_body_started} = 1;
+		if ($empty_lines > 0)
+		{	# re-insert leading white if any nonempty lines exist
+			$multiline = ("\015\012" x $empty_lines) . $multiline;
+			$empty_lines = 0;
+		}
+	}
+
+	while ($multiline =~ /\015\012\015\012\z/)
+	{	# count & strip trailing empty lines
+		chop $multiline; chop $multiline;
+		$empty_lines++;
+	}
+
+	$self->{canonicalize_body_empty_lines} = $empty_lines;
+	return $multiline;
 }
 
 sub finish_body
